pub enum SocResetReason {
Show 19 variants
ChipPowerOn = 1,
CoreSw = 3,
CoreDeepSleep = 5,
CoreMwdt0 = 7,
CoreMwdt1 = 8,
CoreRtcWdt = 9,
Cpu0Mwdt0 = 11,
Cpu0Sw = 12,
Cpu0RtcWdt = 13,
SysBrownOut = 15,
SysRtcWdt = 16,
Cpu0Mwdt1 = 17,
SysSuperWdt = 18,
CoreEfuseCrc = 20,
CoreUsbUart = 21,
CoreUsbJtag = 22,
Cpu0Jtag = 24,
RtcBrownOut = 25,
CpuLockup = 26,
}Expand description
SOC Reset Reason (ESP32-C61).
Parsed from ESP-IDF soc_reset_reason_t in reset_reasons.h.
Variants
ChipPowerOn = 1
Power on reset
In ESP-IDF this value (0x01) can also be ChipBrownOut (VDD voltage
not stable, resets the chip); that is not distinguishable in a Rust enum.
CoreSw = 3
Software resets the digital core (hp system) by LP_AON_HPSYS_SW_RESET
CoreDeepSleep = 5
Deep sleep reset the digital core (hp system)
CoreMwdt0 = 7
Main watch dog 0 resets digital core (hp system)
CoreMwdt1 = 8
Main watch dog 1 resets digital core (hp system)
CoreRtcWdt = 9
RTC watch dog resets digital core (hp system)
Cpu0Mwdt0 = 11
Main watch dog 0 resets CPU 0
Cpu0Sw = 12
Software resets CPU 0 by LP_AON_CPU_CORE0_SW_RESET
Cpu0RtcWdt = 13
RTC watch dog resets CPU 0
SysBrownOut = 15
VDD voltage is not stable and resets the digital core
SysRtcWdt = 16
RTC watch dog resets digital core and rtc module
Cpu0Mwdt1 = 17
Main watch dog 1 resets CPU 0
SysSuperWdt = 18
Super watch dog resets the digital core and rtc module
CoreEfuseCrc = 20
eFuse CRC error resets the digital core (hp system)
CoreUsbUart = 21
USB UART resets the digital core (hp system)
CoreUsbJtag = 22
USB JTAG resets the digital core (hp system)
Cpu0Jtag = 24
JTAG resets CPU 0
RtcBrownOut = 25
RTC power glitch resets system
CpuLockup = 26
CPU lockup resets
Implementations
Sourceimpl SocResetReason
impl SocResetReason
Sourcepub const fn from_repr(discriminant: usize) -> Option<SocResetReason>
pub const fn from_repr(discriminant: usize) -> Option<SocResetReason>
Try to create Self from the raw representation